@@ -1,15 +1,32 @@
 from decimal import Decimal
+from datetime import datetime
+from StringIO import StringIO
 import logging
 import csv
 import re
-from pybrowscap.loader import Browscap
+from pybrowscap.loader import Browscap, TYPE_CSV
+import locale
 
 log = logging.getLogger(__name__)
 
+# Url where latest version of csv browscap data file is located
 URL = 'http://browsers.garykeith.com/stream.asp?BrowsCapCSV'
 
+
 def load_file(browscap_file_path):
+    """
+    Loading browscap csv data file, parsing in into accessible python
+    form and returning a new Browscap class instance with all appropriate data.
+
+    If something went wrong, Exception is raised
+
+    """
     def replace_defaults(line, defaults):
+        """
+        Replaces 'default' values for a line with parent line value and
+        converting it into native python value.
+
+        """
         new_line = {}
         for feature, value in line.iteritems():
             if value == 'default':
@@ -35,13 +52,25 @@ def load_file(browscap_file_path):
             log.info('Reading browscap source file')
             dialect = csv.Sniffer().sniff(csvfile.read(4096))
             csvfile.seek(0)
-            log.info('Removing fileinfo section')
+            log.info('Getting file version and release date')
             csvfile.readline()
-            csvfile.readline()
-            reader        = csv.DictReader(csvfile, dialect=dialect)
-            defaults      = {}
+            line = csv.reader(StringIO(csvfile.readline())).next()
+            try:
+                version = int(line[0])
+                old_locale = locale.getlocale()
+                locale.setlocale(locale.LC_TIME, locale.normalize('en_US.utf8'))
+                release_date = datetime.strptime(line[1][:-6], '%a, %d %b %Y %H:%M:%S')
+            except Exception:
+                log.exception('Error while getting file version and release date')
+                version = None
+                release_date = None
+            else:
+                locale.setlocale(locale.LC_TIME, old_locale)
+            log.info('Reading browscap user-agent data')
+            reader = csv.DictReader(csvfile, dialect=dialect)
+            defaults = {}
             browscap_data = {}
-            regex_cache   = []
+            regex_cache = []
             for line in reader:
                 if line['Parent'] == 'DefaultProperties':
                     continue
@@ -56,7 +85,10 @@ def load_file(browscap_file_path):
                 ua_regex = '^%s$' % ua_regex
                 browscap_data.update({ua_regex: line})
                 regex_cache.append(re.compile(ua_regex))
-        return Browscap(browscap_data, regex_cache)
+        return Browscap(
+            browscap_data, regex_cache, browscap_file_path, TYPE_CSV,
+            version, release_date
+        )
     except Exception:
         log.exception('Error while reading browscap source file')
-        raise
+        raise
\ No newline at end of file
